@@ -1,8 +1,7 @@
 #---------------------------------------------------------------------
-# $Id: DNS.pm 2107 2008-09-27 20:42:32Z cjm $
 package WebService::NFSN::DNS;
 #
-# Copyright 2007 Christopher J. Madsen
+# Copyright 2010 Christopher J. Madsen
 #
 # Author: Christopher J. Madsen <perl@cjmweb.net>
 # Created:  3 Apr 2007
@@ -15,7 +14,7 @@ package WebService::NFSN::DNS;
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See either the
 # GNU General Public License or the Artistic License for more details.
 #
-# Access the NearlyFreeSpeech.NET DNS API
+# ABSTRACT: Access NFSN DNS information
 #---------------------------------------------------------------------
 
 use 5.006;
@@ -27,7 +26,7 @@ use base 'WebService::NFSN::Object';
 #=====================================================================
 # Package Global Variables:
 
-our $VERSION = '0.07';
+our $VERSION = '0.09';
 
 #=====================================================================
 BEGIN {
@@ -57,8 +56,9 @@ WebService::NFSN::DNS - Access NFSN DNS information
 
 =head1 VERSION
 
-This document describes version 0.07 of WebService::NFSN::DNS, released September 28, 2008 as part of WebService-NFSN version 0.08.
-
+This document describes version 0.09 of
+WebService::NFSN::DNS, released November 11, 2010
+as part of WebService-NFSN version 0.09.
 
 =head1 SYNOPSIS
 
@@ -252,3 +252,47 @@ automatically when any change is made to the domain.
 =head1 SEE ALSO
 
 L<WebService::NFSN>
+
+=head1 AUTHOR
+
+Christopher J. Madsen  S<C<< <perl AT cjmweb.net> >>>
+
+Please report any bugs or feature requests to
+S<C<< <bug-WebService-NFSN AT rt.cpan.org> >>>,
+or through the web interface at
+L<http://rt.cpan.org/Public/Bug/Report.html?Queue=WebService-NFSN>
+
+You can follow or contribute to WebService-NFSN's development at
+git://github.com/madsen/webservice-nfsn.git.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2010 by Christopher J. Madsen.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=head1 DISCLAIMER OF WARRANTY
+
+BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
+FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN
+OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES
+PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER
+EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE
+ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE SOFTWARE IS WITH
+YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL
+NECESSARY SERVICING, REPAIR, OR CORRECTION.
+
+IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
+WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
+REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENSE, BE
+LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL,
+OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE
+THE SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
+RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
+FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
+SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
+SUCH DAMAGES.
+
+=cut
